Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(157)

Unified Diff: net/cert/cert_verify_proc_ios.h

Issue 1810153002: Adding iOS OpenSSL Implementation (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixing more nits. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/cert/cert_verify_proc_ios.h
diff --git a/net/cert/cert_verify_proc_mac.h b/net/cert/cert_verify_proc_ios.h
similarity index 65%
copy from net/cert/cert_verify_proc_mac.h
copy to net/cert/cert_verify_proc_ios.h
index 3c87edd7a48f5678dbff643e4be602fa971034d4..e965a486e037aa8e1ed10e0cc8b5c1f7797c5572 100644
--- a/net/cert/cert_verify_proc_mac.h
+++ b/net/cert/cert_verify_proc_ios.h
@@ -1,25 +1,25 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright (c) 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef NET_CERT_CERT_VERIFY_PROC_MAC_H_
-#define NET_CERT_CERT_VERIFY_PROC_MAC_H_
+#ifndef NET_CERT_CERT_VERIFY_PROC_IOS_H_
+#define NET_CERT_CERT_VERIFY_PROC_IOS_H_
#include "net/cert/cert_verify_proc.h"
namespace net {
// Performs certificate path construction and validation using OS X's
// Security.framework.
-class CertVerifyProcMac : public CertVerifyProc {
+class CertVerifyProcIOS : public CertVerifyProc {
public:
- CertVerifyProcMac();
+ CertVerifyProcIOS();
bool SupportsAdditionalTrustAnchors() const override;
bool SupportsOCSPStapling() const override;
protected:
- ~CertVerifyProcMac() override;
+ ~CertVerifyProcIOS() override;
private:
int VerifyInternal(X509Certificate* cert,
@@ -33,4 +33,4 @@ class CertVerifyProcMac : public CertVerifyProc {
} // namespace net
-#endif // NET_CERT_CERT_VERIFY_PROC_MAC_H_
+#endif // NET_CERT_CERT_VERIFY_PROC_IOS_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -1,25 +1,25 @@
#include "net/cert/cert_verify_proc.h"
namespace net {
-// Performs certificate path construction and validation using OS X's
+// Performs certificate path construction and validation using iOS's
// Security.framework.